Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(822)

Unified Diff: src/gpu/gl/GrGLRenderTarget.h

Issue 702413003: Make GrGpuResource::gpuMemorySize non-virtual w/ onGpuMemorySize virtual impl (Closed) Base URL: https://skia.googlesource.com/skia.git@priv
Patch Set: rebase Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/gl/GrGLPathRange.h ('k') | src/gpu/gl/GrGLRenderTarget.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/gl/GrGLRenderTarget.h
diff --git a/src/gpu/gl/GrGLRenderTarget.h b/src/gpu/gl/GrGLRenderTarget.h
index 0f041600ee1ba5b38fdc470fd86074c2e1b66f6c..b81bbed4b2ee746ad4173c3d783d2420f62e0273 100644
--- a/src/gpu/gl/GrGLRenderTarget.h
+++ b/src/gpu/gl/GrGLRenderTarget.h
@@ -58,8 +58,6 @@ public:
}
}
- virtual size_t gpuMemorySize() const SK_OVERRIDE;
-
protected:
// The public constructor registers this object with the cache. However, only the most derived
// class should register with the cache. This constructor does not do the registration and
@@ -72,6 +70,9 @@ protected:
virtual void onAbandon() SK_OVERRIDE;
virtual void onRelease() SK_OVERRIDE;
+ // In protected because subclass GrGLTextureRenderTarget calls this version.
+ virtual size_t onGpuMemorySize() const SK_OVERRIDE;
+
private:
GrGLuint fRTFBOID;
GrGLuint fTexFBOID;
@@ -82,7 +83,7 @@ private:
// we want the rendering to be at top left (GL has origin in bottom left)
GrGLIRect fViewport;
// gpuMemorySize() needs to know what how many color values are owned per pixel. However,
// abandon and release zero out the IDs and the cache needs to know the size even after those
// actions.
uint8_t fColorValuesPerPixel;
@@ -82,7 +83,7 @@ private:
// we want the rendering to be at top left (GL has origin in bottom left)
GrGLIRect fViewport;
- // gpuMemorySize() needs to know what how many color values are owned per pixel. However,
+ // onGpuMemorySize() needs to know what how many color values are owned per pixel. However,
// abandon and release zero out the IDs and the cache needs to know the size even after those
// actions.
« no previous file with comments | « src/gpu/gl/GrGLPathRange.h ('k') | src/gpu/gl/GrGLRenderTarget.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698